Forum
=====

`Discourse <https://discourse.org/>`__ is available at `forum.example.com`.

The user with administrative rights, the
Discourse version and other variables are documented in `this file
<https://lab.enough.community/main/infrastructure/blob/master/playbooks/forum/roles/discourse/defaults/main.yml>`__
and can be modified in the
`~/.enough/example.com/inventory/host_vars/forum-host/forum.yml`
file.
